MetricsData class

Represents a snapshot of system metrics (CPU, memory, thread count, timestamp).

Constructors

MetricsData({required double? cpuUsage, required int memoryUsage, required DateTime timestamp, int? threadCount})
Creates a new MetricsData instance.

Properties

cpuUsage → double?
final
hashCode → int
The hash code for this object.
no setterinherited
memoryUsage → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadCount → int?
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited